@@ -21,6 +21,10 @@ Binary_Property : [
 'Default_Ignorable_Code_Point',
 'Deprecated',
 'Diacritic',
+'Emoji',
+'Emoji_Component',
+'Emoji_Modifier',
+'Emoji_Presentation',    
 'Expands_On_NFC',
 'Expands_On_NFD',
 'Expands_On_NFKC',
